* ====================================== ;
* Replicating Fama and French 2001
* ====================================== ;

* ====================================== ;
* Step 0 - Upload Compustat Data
* ====================================== ;
use "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Comp_FF2001.dta", clear


* ====================================== ;
* Step 1 - Creat key variables
* ====================================== ;

*Create preferred stock
gen preferred=pstkl //preferred stock equals preferred stock liquidating value
replace preferred=pstkrv if preferred==. //set preferred stock equal to redemption value if liquidating value is missing
replace preferred=pstk if preferred==. //set preferred stock equal to par value if both, liquidating and redemption value are missing


*Create Shareholder's equity
gen be=seq
replace be=ceq+pstk if be==.  //If shareholder's equity is missing set be to common equity+preferred stock
replace be=at-lt if be==. //set be equal to assets - liabilities if be still missing

replace txditc=0 if txditc==. // set missing values to zero because they do not require firm to have non-missing value

*Create book_equity
gen book_equity=be-preferred+txditc

*Create market value of equity
gen market_equity=prcc_f*csho //closing price * shares outstanding at fiscal year end

*Create market value of firm
gen market_value=at-book_equity+market_equity 

*Create earnings before interes
replace txdi=0 if txdi==.
gen ebi=ib+xint+txdi //earnings before extraordinary+interest expense+income statament deferred taxes

*Create earnings to common
gen earnings_common=ib-dvp+txdi //earnings before extraordinary-preferred dividends+income statament deferred taxes

*Create dividend payer variable
gen payer=0
replace payer=1 if dvpsx_f>0 & dvpsx_f!=.  //set payer to 1 if positive non-missing dividends

gen year=year(datadate)

gen liability=at-book_equity

replace xrd=0 if xrd==. //set missing R&D to zero because it is not a required filter


* ====================================== ;
* Step 2 - Apply filters
* ====================================== ;

*create lagged assets to apply the filter
sort gvkey year
by gvkey: gen lagged_at=at[_n-1]
replace lagged_at=. if year[_n-1]!=year-1

* remove firms that have missing assets in year t or t-1
drop if at==. | lagged_at==.

*remove firms with missing price or shares outstanding
drop if prcc_f==. | csho==.

* remove firms with missing income, interest, pref dividends, dividends on ex date or preferred stock
drop if ib==. | xint==. | dvp==. | dvpsx_f==. | preferred==.

drop if be==.

* remove firms with book_equity<$250,000 or assets<$500,000; total assets and be are reported in millions in compustat
drop if book_equity<0.25 | at<0.5

*remove financial and utility firms
* SIC code in compustat is saved as character
destring sic, replace
drop if sic>=6000 & sic<=6999 //drop financial firms
drop if sic>=4900 & sic<=4949 //drop utilities

keep if exchg>=11 & exchg<=19

*keep if exchg==11 | exchg==12 | exchg==14

save "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Comp_FF2001_clean.dta", replace


* ====================================== ;
* Step 3 - Analysis
* ====================================== ;

use "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Comp_FF2001_clean.dta", clear

sort year
*count the number of firms in a given year
*count the number of payers in a given year, since payer is a 0/1 variable, the easiest way to count is to sum across
collapse (sum) number_payers=payer (count) number_firms=payer, by (year)

gen percent_payers=number_payers/number_firms
gen percent_non_payers=1-percent_payers

*plot percent of payers
twoway (line percent_payers year, sort)


* ==================================================== New code after class ======================================================== ;

* Table 1 analysis ******************************************************************************************************************
*Original sample 1963-1998
summarize percent_payers percent_non_payers number_firms
*1963-1977
summarize percent_payers percent_non_payers if year>=1963 & year<=1977
*1978-1998
summarize percent_payers percent_non_payers if year>=1978 & year<=1998
* you can do other subsamples as well (i.e. every 5 years, but you have a model here how to do it)


*Table 3 analysis ********************************************************************************************************************
use "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Comp_FF2001_clean.dta" , clear

* Fama and French calculate aggregate values of variables that they form ratios on 
* so we will create aggregate earnings (assets, R&D, earnings to common, etc) for each year and group (payers vs non-payers)
* we will use collapse statement for this and sort data based on year and payer (again payer will help us divide sample into payers and non-payers)
sort year payer

*after collapse statement you should have 2 observations (rows) for each year, one for payers and one for non-payers
collapse (sum) at lagged_at ebi earnings_common book_equity market_equity market_value liability, by (year payer)

*generate ratios based on aggregate values
gen investment=(at-lagged_at)/at
gen e_at=ebi/at
gen y_be=earnings_common/book_equity
gen v_a=market_value/at
gen l_a=liability/at

*Create results that you can include in a table
sort payer
by payer: summarize e_at y_be v_a at l_a investment
by payer: summarize e_at y_be v_a at l_a investment if year>=1963 & year<=1977
by payer: summarize e_at y_be v_a at l_a investment if year>=1978 & year<=1998


*Table 9 analysis **********************************************************************************************************************
* Size breakpoints NYSE only but for all years as FF allow size breakpoints to vary because size has increased significantly
use "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Comp_FF2001_clean.dta" , clear
keep if exchg==11 //NYSE firms in compustat
sort year
drop if market_equity==.
collapse (p20) size20=market_equity (p50) size50=market_equity, by (year)

gen one=1 //create a simple variable for merging with investment and profitability portfolio breakpoints because those will be average across years so cannot merge on year
save "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\NYSE_breakpoints63_77.dta", replace


use "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Comp_FF2001_clean.dta" , clear
keep if year<=1977
*create firm level ratios
gen investment=(at-lagged_at)/at
gen e_at=ebi/at

*merge NYSE size breakpoints
sort year
merge m:1 year using "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\NYSE_breakpoints63_77.dta"
keep if _merge==3
drop _merge

* create percentile breakpoints for profitability and investment and assign firms into portfolios
* note we need the percentile breakpoints as we will use average of these in the future
* if we did not need the actual percentile breakpoints, we could use the xtile function
sort year
drop if e_at==. | investment==.
by year: egen profit_33 = pctile(e_at), p(33)
by year: egen profit_67 = pctile(e_at), p(67)
by year: egen invest_33 = pctile(investment), p(33)
by year: egen invest_67 = pctile(investment), p(67)
* we cannot use collapse command here because we want to keep individual firms, collapse would only keep p33 and p67

*Assign companies to portfolios independently
gen profit_portfolio=1
replace profit_portfolio=2 if e_at > profit_33
replace profit_portfolio=3 if e_at > profit_67

gen invest_portfolio=1
replace invest_portfolio=2 if investment > invest_33
replace invest_portfolio=3 if investment > invest_67

gen size_portfolio=1
replace size_portfolio=2 if market_equity > size20
replace size_portfolio=3 if market_equity > size50
* Save the data
save "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Ind_27_portfolios_63_77.dta", replace
* Calculate number of payers and all firms in each portfolio for each year, so that we can find proportion of payers
sort profit_portfolio invest_portfolio size_portfolio year
collapse (sum) payer (count) num_firms=payer, by (profit_portfolio invest_portfolio size_portfolio year)
gen proportion_payers=payer/num_firms

*find average proportion of payers for each portfolio (across years 63-77)
collapse (mean) proportion_payers, by (profit_portfolio invest_portfolio size_portfolio) // use collapse instead of summarize because we need this as a dataset
* our results are not identical, but they do follow the same trend.
save "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Avg_proportions_63_77.dta", replace


*Table 10 analysis ****************************************************************************************************************

*Big picture: 1) we need breakpoints for investment and profitability portfolios, which will be the same across all years
*			  2) we need NYSE breakpoints for size which will vary across years
*			  3) we need to allocate all firms from 1978-98 into one of the 27 portfolios and determine expected proportion of payers based on 63-77 proportions
*			  4) we need proportions of payers in each of the 27 portfolios for the 1963-77 ( as calculated for Table 8), which will be the same across all years but vary across portfolios
*			  5) we will be merging 4 different datasets

*start with investment and profit breakpoints, which should be averaged across 1963-1977 period
use "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Ind_27_portfolios_63_77.dta", clear
collapse (mean) profit_33 profit_67 invest_33 invest_67
gen one=1 //create variable 1 for merging with NYSE size breakpoints

*merge with NYSE size breakpoints
merge 1:m one using "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\NYSE_breakpoints63_77.dta"
keep if _merge==3
drop _merge one

* merge in all the firms and assign to 27 portfolios (3 by 3 by 3)
merge 1:m year using "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Comp_FF2001_clean.dta" 
keep if _merge==3
drop _merge
gen investment=(at-lagged_at)/at
gen e_at=ebi/at

*Assign companies to portfolios independently (you can copy the code above, the reason that we are repearing this now is that we are using data through 1998)
gen profit_portfolio=1
replace profit_portfolio=2 if e_at > profit_33
replace profit_portfolio=3 if e_at > profit_67

gen invest_portfolio=1
replace invest_portfolio=2 if investment > invest_33
replace invest_portfolio=3 if investment > invest_67

gen size_portfolio=1
replace size_portfolio=2 if market_equity > size20
replace size_portfolio=3 if market_equity > size50

*Obtain the actual number of payers and total number of firms in each of the 27 portfolios in each of the years
sort profit_portfolio invest_portfolio size_portfolio year
collapse (sum) number_payers=payer (count) number_firms=payer, by (profit_portfolio invest_portfolio size_portfolio year)

*merge with average proportions across different portfolios, there is 1 obs per each of the 27 portfolios in using dataset but one for each year in master
merge m:1 profit_portfolio invest_portfolio size_portfolio using "C:\Users\bnikolic\Documents\USD\Teaching\Spring 2020\MFIN 516\STATA\Avg_proportions_63_77.dta"
keep if _merge==3
drop _merge

*create for each portfolio-year expected number of dividend payers by multiplying number of firms at that time by the proportion of payers from 63-77 for that portfolio
gen expected_number_payers=number_firms*proportion_payers
* now add expected number of payers, actual number of payers, and total number of firms across all 27 portfolios in a given year
sort year
collapse (sum) number_firms expected_number_payers actual_number_payers=number_payers , by (year)

*calculate actual and expected proportion of payers (controlling for characteristics) in a given year
gen actual_prop_payer=actual_number_payers/number_firms
gen expected_prop_payer=expected_number_payers/number_firms
gen difference= expected_prop_payer-actual_prop_payer

keep year actual_prop_payer expected_prop_payer difference

*print the data for years 1978-1998
list if year>1977


